#
# spec file for package ghc-network-uri
#
# Copyright (c) 2020 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name network-uri
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        2.6.3.0
Release:        lp152.1.1
Summary:        URI manipulation
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-parsec-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-template-haskell-devel
%if %{with tests}
BuildRequires:  ghc-HUnit-devel
BuildRequires:  ghc-criterion-devel
BuildRequires:  ghc-test-framework-devel
BuildRequires:  ghc-test-framework-hunit-devel
BuildRequires:  ghc-test-framework-quickcheck2-devel
%endif

%description
This package provides facilities for parsing and unparsing URIs, and creating
and resolving relative URI references, closely following the URI spec,
<http://www.ietf.org/rfc/rfc3986.txt IETF RFC 3986>.

== Backward-compatibility

In 'network-2.6' the "Network.URI" module was split off from the 'network'
package into this package. If you're using the "Network.URI" module you can be
backward compatible and automatically get it from the right package by using
the </package/network-uri-flag network-uri-flag pseudo-package> in your
'.cabal' file's build-depends (along with dependencies for both 'network-uri'
and 'network'):

> build-depends: > network-uri-flag == 0.1.*

Or you can do the same manually by adding this boilerplate to your '.cabal'
file:

> flag network-uri > description: Get Network.URI from the network-uri package
> default: True > > library > -- ... > if flag(network-uri) > build-depends:
network-uri >= 2.6, network >= 2.6 > else > build-depends: network-uri < 2.6,
network < 2.6

That is, get the module from either 'network < 2.6' or from 'network-uri >=
2.6'.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md README.md

%changelog
* Wed May  6 2020 Peter Simons <psimons@suse.com>
- Downgrade to version 2.6.3.0. Upstream has retracted 2.7.0.0.
* Fri Feb  7 2020 psimons@suse.com
- Update network-uri to version 2.7.0.0.
  Upstream added a new change log file in this release. With no
  previous version to compare against, the automatic updater cannot
  reliable determine the relevante entries for this release.
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Sat Oct 20 2018 Peter Simons <psimons@suse.com>
- Use https URL to refer to bugs.opensuse.org.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Wed May 16 2018 psimons@suse.com
- Prefer the new %%license attribute over %%doc.
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Thu Jun  8 2017 psimons@suse.com
- Update to version 2.6.1.0 revision 1.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 2.6.1.0 revision 0 with cabal2obs.
* Mon Mar 21 2016 mimi.vx@gmail.com
- update to 2.6.1.0
* Tue May  5 2015 mimi.vx@gmail.com
- update to 2.6.0.3
* Mon May  4 2015 mimi.vx@gmail.com
- update to 2.6.0.2
  * no upstream changelog
* Sat Apr 11 2015 mimi.vx@gmail.com
- initial commit of network-uri
